export default {
  // 日期纠正
  validateDate: function validateDate(val, config) {
    if (config === void 0) {
      config = {};
    }

    var type = config.type;
    var min = config.min;
    var max = config.max;
    var split = config.split || '-';
    var timeSplit = config.timeSplit || ':';
    var onError = config.onError;
    var value = val;
    var selectDate = value.toDate(split, timeSplit);
    var e = config.event || {};

    if (min && (min.isYear(split) || min.isQuarter(split) || min.isMonth(split) || min.isDate(split) || min.isDateTime(split, timeSplit) || min.isTime(timeSplit))) {
      if (type === 'year' && selectDate.compareYear(min.toDate(split, timeSplit)) === -1) {
        if (onError) {
          onError(e, {
            errMsg: locale('不能小于', 'hint_cannot_be_less_than') + min,
            select: value,
            min: min,
            value: value
          });
          return false;
        }

        value = min;
      } else if (type === 'quarter' && selectDate.compareMonth(min.toDate(split, timeSplit)) === -1) {
        if (onError) {
          onError(e, {
            errMsg: locale('不能小于', 'hint_cannot_be_less_than') + min,
            select: value,
            min: min,
            value: value
          });
          return false;
        }

        value = min;
      } else if (type === 'month' && selectDate.compareMonth(min.toDate(split, timeSplit)) === -1) {
        if (onError) {
          onError(e, {
            errMsg: locale('不能小于', 'hint_cannot_be_less_than') + min,
            select: value,
            min: min,
            value: value
          });
          return false;
        }

        value = min;
      } else if (type === 'date' && selectDate.compareDate(min.toDate(split, timeSplit)) === -1) {
        if (onError) {
          onError(e, {
            errMsg: locale('不能小于', 'hint_cannot_be_less_than') + min,
            select: value,
            min: min,
            value: value
          });
          return false;
        }

        value = min;
      } else if (type === 'datetime' && selectDate.compareDateTime(min.toDate(split, timeSplit)) === -1) {
        if (onError) {
          onError(e, {
            errMsg: locale('不能小于', 'hint_cannot_be_less_than') + min,
            select: value,
            min: min,
            value: value
          });
          return false;
        }

        value = min;
      } else if (type === 'time' && selectDate.compareTime(min.toDate(split, timeSplit)) === -1) {
        if (onError) {
          onError(e, {
            errMsg: locale('不能小于', 'hint_cannot_be_less_than') + min,
            select: value,
            min: min,
            value: value
          });
          return false;
        }

        value = min;
      }
    }

    if (max && (max.isYear(split) || max.isMonth(split) || max.isQuarter(split) || max.isDateTime(split, timeSplit) || max.isDate(split) || max.isTime(timeSplit))) {
      if (type === 'year' && selectDate.compareYear(max.toDate(split, timeSplit)) === 1) {
        if (onError) {
          onError(e, {
            errMsg: locale('不能大于', 'hint_cannot_be_greater_than') + max,
            select: value,
            max: max,
            value: value
          });
          return false;
        }

        value = max;
      } else if (type === 'quarter' && selectDate.compareMonth(max.toDate(split, timeSplit)) === 1) {
        if (onError) {
          onError(e, {
            errMsg: locale('不能大于', 'hint_cannot_be_greater_than') + max,
            select: value,
            max: max,
            value: value
          });
          return false;
        }

        value = max;
      } else if (type === 'month' && selectDate.compareMonth(max.toDate(split, timeSplit)) === 1) {
        if (onError) {
          onError(e, {
            errMsg: locale('不能大于', 'hint_cannot_be_greater_than') + max,
            select: value,
            max: max,
            value: value
          });
          return false;
        }

        value = max;
      } else if (type === 'date' && selectDate.compareDate(max.toDate(split, timeSplit)) === 1) {
        if (onError) {
          onError(e, {
            errMsg: locale('不能大于', 'hint_cannot_be_greater_than') + max,
            select: value,
            max: max,
            value: value
          });
          return false;
        }

        value = max;
      } else if (type === 'time' && selectDate.compareTime(max.toDate(split, timeSplit)) === 1) {
        if (onError) {
          onError(e, {
            errMsg: locale('不能大于', 'hint_cannot_be_greater_than') + max,
            select: value,
            max: max,
            value: value
          });
          return false;
        }

        value = max;
      } else if (type === 'datetime' && selectDate.compareDateTime(max.toDate(split, timeSplit)) === 1) {
        if (onError) {
          onError(e, {
            errMsg: locale('不能大于', 'hint_cannot_be_greater_than') + max,
            select: value,
            max: max,
            value: value
          });
          return false;
        }

        value = max;
      }
    }

    return value;
  },
  // 计算区间, 区间内
  validateRange: function validateRange(values, onError) {
    var start = '';
    var end = '';

    if (Array.isArray(values) && values.length === 2) {
      start = values[0];
      end = values[1];
    }

    if (!start || !end) {
      if (onError) {
        onError(e, {
          errMsg: locale('无效的日期格式', 'hint_invalid_date') + max,
          select: values,
          value: values
        });
        return false;
      }

      return true;
    }

    if (start.toDate().getTime() < end.toDate().getTime()) {
      if (onError) {
        onError(e, {
          errMsg: locale('开始时间不能大于结束时间', 'hint_start_greater_end_time'),
          select: values,
          value: values
        });
        return false;
      }

      start = end;
    }

    return [start, end];
  }
};